@@ -171,7 +171,6 @@ public class TimeZoneNames_ks_Deva extends TimeZoneNamesBundle {
             { "MST7MDT", America_Mountain },
             { "PST8PDT", America_Pacific },
             { "Asia/Gaza", Europe_Eastern },
-            { "Asia/Amman", Europe_Eastern },
             { "Africa/Lome", GMT },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Hebron", Europe_Eastern },
@@ -198,7 +197,6 @@ public class TimeZoneNames_ks_Deva extends TimeZoneNamesBundle {
             { "America/Aruba", Atlantic },
             { "America/Boise", America_Mountain },
             { "America/Thule", Atlantic },
-            { "Asia/Damascus", Europe_Eastern },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin", GMT },
@@ -330,6 +328,7 @@ public class TimeZoneNames_ks_Deva extends TimeZoneNamesBundle {
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
